==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/it/modify.php <==
<?php

global $modify_text;
$modify_text = array (

'modify'			=>	'Modifica',
'noticefrom'		=>	'Informazione da',
'hasopened'			=>	'ha APERTO UN NUOVO TASK su Flyspray, e l\'ha assegnato a te:',
'newtask'			=>	'Nuovo Task:',
'moreinfonew'		=>	'Puoi trovare piu\' informazioni su questo bug alla pagina Flyspray:',
'newtaskcategory'	=>	'Un nuovo task e\' stato aperto in questa categoria',
'categoryowner'		=>	'Stai ricevendo questo messaggio perch&eacute; sei il gestore della categoria.',
'tasksummary'		=>	'Riassunto del task:',
'newtaskadded'		=>	'Il tuo nuovo task e\' stato aggiunto.',
'waitwhiletransfer'	=>	'Aspetta mentre vieni trasferito...',
'clicknowait'		=>	'Clicca qui se non vuoi aspettare.',
'summaryanddetails'	=>	'Devi riempire sia il riassunto che i dettagli.',
'goback'			=>	'Vai indietro.',

'summary'			=>	'Riassunto:',
'tasktype'			=>	'Tipo di task:',
'category'			=>	'Categoria:',
'status'			=>	'Status:',
'operatingsystem'	=>	'Sistema operativo:',
'severity'			=>	'Gravita\':',
'reportedversion'	=>	'Riportato nella Versione:',
'dueinversion'		=>	'Dovuto per la Versione:',
'percentcomplete'	=>	'Percentuale di completamento:',
'summary'			=>	'Riassunto:',
'details'			=>	'Dettagli:',

'messagefrom'		=>	'Questo e\' un messaggio del sistema di bug tracking Flyspray a',
'hasjustmodified'	=>	'ha appena modificato il seguente task.',
'changedfields'		=>	'I campi modificati sono indiviruati con due asterischi (**)',
'moreinfomodify'	=>	'Puoi avere maggiori informazioni su questo task all\' URL seguente:',

'task'				=>	'Task',
'nolongerassigned'	=>	'Il task seguente non e\' piu\' assegnato a te.  Ora e\' assegnato a',
'hasassigned'		=>	'ti ha assegnato il seguente task Flyspray:',

'taskupdated'		=>	'Il task e\' stato aggiornato.',

'hasclosedassigned'	=>	'ha chiuso il seguente task Flyspray che ti era stato assegnato:',
'reasonforclosing'	=>	'Il motivo della chiusura e\':',
'noone'				=>	'Nessuno',
'unassigned'		=>	'Non assegnato',

'hasclosed'			=>	'ha chiuso il seguente task.',
'youonnotify'		=>	'Ricevi questo messaggio perche\' sei sulla lista di notifica.',
'taskclosed'		=>	'Il task e\' stato chiuso.',
'returntotask'		=>	'Ritorna ai dettagli del task',
'backtoindex'		=>	'Torna indietro alla lista dei task',
'noclosereason'		=>	'Non hai selezionalto un motivo per chiudere questo task.',
'hasreopened'		=>	'ha riaperto il seguente task Flyspray che avevi chiuso:',
'taskreopened'		=>	'Il task e\' stato riaperto.',
'backtotask'		=>	'Torna indietro al task.',

'commentadded'		=>	'Il Commento e\' stato aggiunto.',
'commenttoassigned'	=>	'ha aggiunto un commento a un task che era stato assegnato:',
'commenttotask'		=>	'ha aggiunto il seguente commento a questo task.',
'nocommententered'	=>	'Tu non dovresti davvero inserire un commento prima di avere cliccato il pulsante di submit.',

'fillinfields'		=>	'Non hai riempito tutti i campi.',
'notcurrentpass'	=>	'Non e\' la tua password attuale!',
'passchanged'		=>	'La tua password e\' cambiata.',
'closewindow'		=>	'Adesso puoi chiudere la finestra.',
'passnomatch'		=>	'Le tue nuove password non coincidono!',

'usernametaken'		=>	'Questo username e\' gia stato scelto.',
'newusercreated'	=>	'Un nuovo account utente e\' stato creato.',
'accountcreated'	=>	'I tuo account utente e\' stato creato.',
'newuserwarning'	=>	'Tieni presente che l\'impostazione dell\'applicazione potrebbe richiedere che il tuo account venga approvato da un amministratore.  Se non riesci a collegarti, questa potrebbe essere la causa.',
'nomatchpass'		=>	'Le password non corrispondono.',
'confirmwrong'		=>	'In codice di conferma non e\' corretto!',
'formnotcomplete'	=>	'La form non &eacute stata completata.',

'groupnametaken'	=>	'Questo nome di gruppo e\' gia stato scelto.',
'newgroupadded'		=>	'Aggiunto nuovo gruppo.',

'optionssaved'		=>	'Ozioni Flyspray salvate.',

'hasuploaded'		=>	'ha caricato un attachment ad un task che ti &eacute; stato assegnato:',
'hasattached'		=>	'ha caricato un attachment al seguente task.',
'filename'			=>	'Nome file:',
'description'		=>	'Descrizione:',
'fileuploaded'		=>	'Il file &eacute; stato caricato.',
'fileerror'			=>	'C\'e\' stato un errore nel caricamento del file.  Forse i permessi sulla directory degli <i>attachment/</i> sono sbagliati.',
'contactadmin'		=>	'Contatta l\'Administrator di questo progetto.',
'selectfileerror'	=>	'Non hai selezionato un file.',

'userupdated'		=>	'I dettagli utente sono stati aggiornati',
'realandemail'		=>	'Non hai riempito i campi Nome Vero e Indirizzo e-mail.',

'groupupdated'		=>	'Definizione del gruppo aggiornata.',
'groupanddesc'		=>	'Non hai riempito i campi Nome gruppo e descrizione.',

'fillallfields'	=>	'Prego riempire tutti i campi.',
'listupdated'		=>	'La Lista e\' stata modificata.',
'listitemadded'		=>	'Nuovo elemento aggiunto alla lista.',

'relatedadded'		=>	'Task correlato aggiunto alla lista.',
'relatederror'		=>	'Questo task e\' gia nella lista dei task correlati.',

'relatedremoved'	=>	'Task correlato rimosso dalla lista.',

'notifyadded'		=>	'Utente aggiunto alla lista di notifica.',
'notifyerror'		=>	'L\'utente e\' gia nella lista di notifica di questo task.',

'notifyremoved'		=>	'Utente rimosso dalla lista di notifica.',

'editcommentsaved'	=>	'Il commento modificato e\' stato salvato.',
'commentdeleted'	=>	'Il commento e\' stato cancellato.',

// Added in version 0.9.5

'project'			=>	'Progetto:',
'gotonewtask'		=>	'Vai al nuovo task appena creato',
'addanother'		=>	'Aggiungi un altro task al progetto',
'projectcreated'	=>	'Il tuo nuovo progetto e\' stato creato. Segui il link sotto per definire le liste di categorie, versioni e sistema operativo',
'customiseproject'	=>	'Personalizza questo progetto',
'projectupdated'	=>	'Le preferenze del progetto sono state aggiornate',
'emptytitle'		=>	'Hai lasciato vuto il titolo del progetto.  torna
indietro e completa.',
'loginbelow'		=>	'Non dovresti tentare di collegarti usando la forma
sotto.',
'attachmentdeleted' => 'L\'allegato e\' stato rimosso',

// Added in 0.9.6

'reminderadded'     =>   'Il tuo promemoria e\' stato aggiunto.',
'reminderdeleted'   =>   'Il promemoria selezionato  stato eliminato.',
'flyspraytask'		=>   'Task Flyspray',
'fieldsmissing'     =>   'Alcuni campi contenevano dati errati o mancanti.',
'relatedinvalid'    =>   'Non c\'e\' questo task.',
'relatedproject'    =>   'Il Task appartiene ad un progetto differente.',
'addanyway'         =>   'Aggiungi comunque',
'cancel'            =>   'Cancella',
'alreadyedited'     =>   'Il task e\' stato modificato da qualcun altro prima che lo salvassi.',
'saveanyway'        =>   'Salva comunque le mie modifichey',
'priority'          =>   'Priorita\'',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/it/modify.php <==
<?php

global $modify_text;
$modify_text = array (

'modify'			=>	'Modifica',
'noticefrom'		=>	'Informazione da',
'hasopened'			=>	'ha APERTO UN NUOVO TASK su Flyspray, e l\'ha assegnato a te:',
'newtask'			=>	'Nuovo Task:',
'moreinfonew'		=>	'Puoi trovare piu\' informazioni su questo bug alla pagina Flyspray:',
'newtaskcategory'	=>	'Un nuovo task e\' stato aperto in questa categoria',
'categoryowner'		=>	'Stai ricevendo questo messaggio perch&eacute; sei il gestore della categoria.',
'tasksummary'		=>	'Riassunto del task:',
'newtaskadded'		=>	'Il tuo nuovo task e\' stato aggiunto.',
'waitwhiletransfer'	=>	'Aspetta mentre vieni trasferito...',
'clicknowait'		=>	'Clicca qui se non vuoi aspettare.',
'summaryanddetails'	=>	'Devi riempire sia il riassunto che i dettagli.',
'goback'			=>	'Vai indietro.',

'summary'			=>	'Riassunto:',
'tasktype'			=>	'Tipo di task:',
'category'			=>	'Categoria:',
'status'			=>	'Status:',
'operatingsystem'	=>	'Sistema operativo:',
'severity'			=>	'Gravita\':',
'reportedversion'	=>	'Riportato nella Versione:',
'dueinversion'		=>	'Dovuto per la Versione:',
'percentcomplete'	=>	'Percentuale di completamento:',
'summary'			=>	'Riassunto:',
'details'			=>	'Dettagli:',

'messagefrom'		=>	'Questo e\' un messaggio del sistema di bug tracking Flyspray a',
'hasjustmodified'	=>	'ha appena modificato il seguente task.',
'changedfields'		=>	'I campi modificati sono indiviruati con due asterischi (**)',
'moreinfomodify'	=>	'Puoi avere maggiori informazioni su questo task all\' URL seguente:',

'task'				=>	'Task',
'nolongerassigned'	=>	'Il task seguente non e\' piu\' assegnato a te.  Ora e\' assegnato a',
'hasassigned'		=>	'ti ha assegnato il seguente task Flyspray:',

'taskupdated'		=>	'Il task e\' stato aggiornato.',

'hasclosedassigned'	=>	'ha chiuso il seguente task Flyspray che ti era stato assegnato:',
'reasonforclosing'	=>	'Il motivo della chiusura e\':',
'noone'				=>	'Nessuno',
'unassigned'		=>	'Non assegnato',

'hasclosed'			=>	'ha chiuso il seguente task.',
'youonnotify'		=>	'Ricevi questo messaggio perche\' sei sulla lista di notifica.',
'taskclosed'		=>	'Il task e\' stato chiuso.',
'returntotask'		=>	'Ritorna ai dettagli del task',
'backtoindex'		=>	'Torna indietro alla lista dei task',
'noclosereason'		=>	'Non hai selezionalto un motivo per chiudere questo task.',
'hasreopened'		=>	'ha riaperto il seguente task Flyspray che avevi chiuso:',
'taskreopened'		=>	'Il task e\' stato riaperto.',
'backtotask'		=>	'Torna indietro al task.',

'commentadded'		=>	'Il Commento e\' stato aggiunto.',
'commenttoassigned'	=>	'ha aggiunto un commento a un task che era stato assegnato:',
'commenttotask'		=>	'ha aggiunto il seguente commento a questo task.',
'nocommententered'	=>	'Tu non dovresti davvero inserire un commento prima di avere cliccato il pulsante di submit.',

'fillinfields'		=>	'Non hai riempito tutti i campi.',
'notcurrentpass'	=>	'Non e\' la tua password attuale!',
'passchanged'		=>	'La tua password e\' cambiata.',
'closewindow'		=>	'Adesso puoi chiudere la finestra.',
'passnomatch'		=>	'Le tue nuove password non coincidono!',

'usernametaken'		=>	'Questo username e\' gia stato scelto.',
'newusercreated'	=>	'Un nuovo account utente e\' stato creato.',
'accountcreated'	=>	'I tuo account utente e\' stato creato.',
'newuserwarning'	=>	'Tieni presente che l\'impostazione dell\'applicazione potrebbe richiedere che il tuo account venga approvato da un amministratore.  Se non riesci a collegarti, questa potrebbe essere la causa.',
'nomatchpass'		=>	'Le password non corrispondono.',
'confirmwrong'		=>	'In codice di conferma non e\' corretto!',
'formnotcomplete'	=>	'La form non &eacute stata completata.',

'groupnametaken'	=>	'Questo nome di gruppo e\' gia stato scelto.',
'newgroupadded'		=>	'Aggiunto nuovo gruppo.',

'optionssaved'		=>	'Ozioni Flyspray salvate.',

'hasuploaded'		=>	'ha caricato un attachment ad un task che ti &eacute; stato assegnato:',
'hasattached'		=>	'ha caricato un attachment al seguente task.',
'filename'			=>	'Nome file:',
'description'		=>	'Descrizione:',
'fileuploaded'		=>	'Il file &eacute; stato caricato.',
'fileerror'			=>	'C\'e\' stato un errore nel caricamento del file.  Forse i permessi sulla directory degli <i>attachment/</i> sono sbagliati.',
'contactadmin'		=>	'Contatta l\'Administrator di questo progetto.',
'selectfileerror'	=>	'Non hai selezionato un file.',

'userupdated'		=>	'I dettagli utente sono stati aggiornati',
'realandemail'		=>	'Non hai riempito i campi Nome Vero e Indirizzo e-mail.',

'groupupdated'		=>	'Definizione del gruppo aggiornata.',
'groupanddesc'		=>	'Non hai riempito i campi Nome gruppo e descrizione.',

'fillallfields'	=>	'Prego riempire tutti i campi.',
'listupdated'		=>	'La Lista e\' stata modificata.',
'listitemadded'		=>	'Nuovo elemento aggiunto alla lista.',

'relatedadded'		=>	'Task correlato aggiunto alla lista.',
'relatederror'		=>	'Questo task e\' gia nella lista dei task correlati.',

'relatedremoved'	=>	'Task correlato rimosso dalla lista.',

'notifyadded'		=>	'Utente aggiunto alla lista di notifica.',
'notifyerror'		=>	'L\'utente e\' gia nella lista di notifica di questo task.',

'notifyremoved'		=>	'Utente rimosso dalla lista di notifica.',

'editcommentsaved'	=>	'Il commento modificato e\' stato salvato.',
'commentdeleted'	=>	'Il commento e\' stato cancellato.',

// Added in version 0.9.5

'project'			=>	'Progetto:',
'gotonewtask'		=>	'Vai al nuovo task appena creato',
'addanother'		=>	'Aggiungi un altro task al progetto',
'projectcreated'	=>	'Il tuo nuovo progetto e\' stato creato. Segui il link sotto per definire le liste di categorie, versioni e sistema operativo',
'customiseproject'	=>	'Personalizza questo progetto',
'projectupdated'	=>	'Le preferenze del progetto sono state aggiornate',
'emptytitle'		=>	'Hai lasciato vuto il titolo del progetto.  torna
indietro e completa.',
'loginbelow'		=>	'Non dovresti tentare di collegarti usando la forma
sotto.',
'attachmentdeleted' => 'L\'allegato e\' stato rimosso',

// Added in 0.9.6

'reminderadded'     =>   'Il tuo promemoria e\' stato aggiunto.',
'reminderdeleted'   =>   'Il promemoria selezionato  stato eliminato.',
'flyspraytask'		=>   'Task Flyspray',
'fieldsmissing'     =>   'Alcuni campi contenevano dati errati o mancanti.',
'relatedinvalid'    =>   'Non c\'e\' questo task.',
'relatedproject'    =>   'Il Task appartiene ad un progetto differente.',
'addanyway'         =>   'Aggiungi comunque',
'cancel'            =>   'Cancella',
'alreadyedited'     =>   'Il task e\' stato modificato da qualcun altro prima che lo salvassi.',
'saveanyway'        =>   'Salva comunque le mie modifichey',
'priority'          =>   'Priorita\'',

// Added in version 0.9.7

'nouserselected'        =>        'Nessun utente selezionato. Seleziona almeno un utente prima di riprovare.',  // Changed in svn r191
'groupswitchupdated'    =>        'Gruppi utenti modificati con successo.',
'takenownership'        =>        'Questo task non ti e\' assegnato.',
'adminrequestmade'      =>        'La tua richiesta  stata trasmessa ad un progect manager.',
'newdepnotify'          =>        'Una nuova dipendenza e\' stata aggiunta al seguente task:',
'dependadded'           =>        'La dipendenza e\'stata aggiunta',
'dependaddfailed'       =>        'Non puoi aggiungere il task come dipendenza in questo momento',
'depremoved'            =>        'La dipendenza e\' stata eliminata',
'newdepis'              =>        'La nuova dipendenza e\'',
'magicurlsent'          =>        'Un messaggio e\' stato inviato al tuo indirizzo di notifica. Contiene un link che ti portera\' ad una pagina per completare questo task.',
'changefspass'          =>        'Cambia la password di Flyspray',
'magicurlmessage'       =>        'Prego csegui questo link per cambiare la tua password Flyspray:',
'erroronform'           =>        'C\'e\' stato un problema su questa form',
'addressused'           =>        'Questo indirizzo e\' stato usato per registrare un\'utenza Flyspray.  Se non stavi aspettando questo messaggio, ignoralo ed eliminalo.  Vai alla seguente Url per completare la registrazione:',
'confirmcodeis'         =>        'Il tuo codice di conferma e\':',
'codesent'              =>        'Il tuo codice di conferma e\' stato inviato. Prego segui le istruzioni contenute nel messaggio.',
'taskmadeprivate'       =>        'Questo task e\' stato reso privato',
'taskmadepublic'        =>        'Questo task e\' stato reso nuovamente pubblico',
'realandnotify'         =>        'Devi riempire il campo nome vero, ed uno tra icampi indirizzo email o jabber id.',

                      
);
?>
